import { useEffect, useRef, useState } from "react";
import PageTitle from "../../components/PageTitle";
import Container from "../../components/Container";
import Modal from "../../components/Modal/Modal";
import useAuthCheck from "../../hooks/AuthCheck";
import { useOrderDetailsQuery } from "../../app/features/order/apiSlice";
import { useReactToPrint } from "react-to-print";
import LoadingCom from "../../components/common/loadingCom";
import useLanguage from "../../hooks/useLanguage";

export default function UserDashboard({ params }) {
  const [logOutModal, setLogOutModal] = useState(false);
  const { data, isFetching } = useOrderDetailsQuery({ orderId: params });
  const authInfo = useAuthCheck();

  const closeLogoutModal = () => {
    setLogOutModal(false);
  };

  // make privet
  useEffect(() => {
    const authInfo = JSON.parse(localStorage.getItem("auth"));
    if (!authInfo) {
      route.push("/");
    }
  }, [authInfo]);

  const componentRef = useRef();
  const handlePrint = useReactToPrint({
    content: () => componentRef.current,
  });
  const language = useLanguage();
  return (
    <>
      <PageTitle
        title={language["Order Details"]}
        pageName={language["Order Details"]}
      />
      <section className="bg-primary-200/5 py-20 box-border">
        <Container>
          {isFetching ? (
            <LoadingCom />
          ) : (
            <>
              {" "}
              {/* status path  start  */}
              <div className=" bg-primary-200 rounded-lg px-5  sm:px-20 py-5 sm:py-10 ">
                <div className=" box-border">
                  <div className="px-4">
                    <div className="flex w-full  relative justify-between items-center">
                      <div
                        className="h-8 w-8 border-8 rounded-full border-white bg-primary-200 relative z-10"
                        style={{ borderColor: "#FFBB38" }}
                      ></div>
                      <div
                        className="h-8 w-8 border-8 rounded-full border-white bg-primary-200 relative z-10"
                        style={{
                          borderColor:
                            data?.order?.order_status > 0 ? "#FFBB38" : "",
                        }}
                      ></div>
                      <div
                        className="h-8 w-8 border-8 rounded-full border-white bg-primary-200 relative z-10"
                        style={{
                          borderColor:
                            data?.order?.order_status > 1 ? "#FFBB38" : "",
                        }}
                      ></div>
                      <div className=" absolute w-full  h-2 bg-white rounded-lg">
                        <div
                          className={`h-full bg-secondary  rounded-lg`}
                          style={{
                            width:
                              data?.order?.order_status == 0
                                ? "0%"
                                : data?.order?.order_status == 1
                                ? "50%"
                                : "100%",
                          }}
                        ></div>
                      </div>
                    </div>
                  </div>
                  <div className="flex w-full justify-between text-lg font-medium text-white pt-2 notranslate">
                    <p>{language["Pending"]}</p>
                    <p>{language["Progress"]}</p>
                    <p>{language["Delivered"]}</p>
                  </div>
                </div>
              </div>
              {/* status path  end  */}
              <div
                className="bg-white lg:p-10 p-3 rounded-xl mt-10"
                ref={componentRef}
              >
                <div id="printSection">
                  <div className="flex justify-between items-center mb-4">
                    <div>
                      <h1 className="text-[26px] font-semibold text-qblack mb-2.5 notranslate">
                        {language["Your Orders"]}
                      </h1>
                      <ul className="flex flex-col space-y-0.5">
                        <li className="text-[22px]n text-[#4F5562] notranslate">
                          {language["Order ID"]}:{" "}
                          <span className="text-[#27AE60]">
                            {data?.order?.order_id}
                          </span>
                        </li>
                        <li className="text-[22px]n text-[#4F5562] notranslate">
                          {language["Address"]}:{" "}
                          <span className="text-[#27AE60]">
                            {data?.order?.received_location}
                          </span>
                        </li>
                        <li className="text-[22px]n text-[#4F5562] notranslate">
                          {language["Payment Method"]}:{" "}
                          <span className="text-[#27AE60]">
                            {data?.order?.payment_method}
                          </span>
                        </li>
                        <li className="text-[22px]n text-[#4F5562] notranslate">
                          {language["Delivery Type"]}:{" "}
                          <span className="text-[#27AE60] capitalize">
                            {data?.order?.order_type}
                          </span>
                        </li>
                      </ul>
                    </div>
                    <div className="">
                      <button
                        type="button"
                        onClick={handlePrint}
                        className="w-[60px] h-[52px] rounded flex space-x-2.5 rtl:space-x-reverse  items-center justify-center primary-bg print:hidden mt-5 sm:mt-0"
                      >
                        <span>
                          <svg
                            width="27"
                            height="26"
                            viewBox="0 0 27 26"
                            fill="none"
                            xmlns="http://www.w3.org/2000/svg"
                          >
                            <path
                              d="M24.9 6.10885H22.0364V0.900017C22.0364 0.402996 21.6334 0 21.1364 0H5.86364C5.36662 0 4.96362 0.402943 4.96362 0.900017V6.10885H2.09999C0.942047 6.10885 0 7.05095 0 8.2089V17.2635C0 18.4214 0.942047 19.3635 2.09999 19.3635H4.96378V24.1947C4.96378 24.6917 5.36672 25.0947 5.8638 25.0947H21.1362C21.6332 25.0947 22.0362 24.6918 22.0362 24.1947V19.3635H24.9C26.058 19.3635 27 18.4214 27 17.2635V8.2089C27 7.05101 26.058 6.10885 24.9 6.10885ZM6.76361 1.80004H20.2363V6.10885H6.76361V1.80004ZM20.2362 23.2947H6.76382C6.76382 23.1188 6.76382 16.149 6.76382 15.9315H20.2362C20.2362 16.1545 20.2362 23.1256 20.2362 23.2947ZM21.1364 11.3936H18.8454C18.3484 11.3936 17.9454 10.9907 17.9454 10.4936C17.9454 9.99654 18.3483 9.5936 18.8454 9.5936H21.1364C21.6334 9.5936 22.0364 9.99654 22.0364 10.4936C22.0364 10.9907 21.6334 11.3936 21.1364 11.3936Z"
                              fill="#222222"
                            ></path>
                          </svg>
                        </span>
                        <span className="text-sm text-qblack notranslate">
                          {language["Print PDF"]}
                        </span>
                      </button>
                    </div>
                  </div>
                  <div className="relative w-full overflow-x-auto overflow-style-none border border-[#EDEDED] box-border mb-10">
                    <table className="w-full text-sm text-left text-gray-500 dark:text-gray-400">
                      <tbody>
                        <tr className="text-[13px] font-medium text-black bg-[#F6F6F6] whitespace-nowrap px-2 border-b default-border-bottom uppercase">
                          <td className=" pl-8 py-4 ltr:pl-10 rtl:pr-10 block whitespace-nowrap rtl:text-right w-[380px] notranslate">
                            {language["Product"]}
                          </td>
                          <td className="py-4 whitespace-nowrap text-center notranslate">
                            {language["quantity"]}
                          </td>
                          <td className="py-4 whitespace-nowrap text-center notranslate">
                            {language["Unit Price"]}
                          </td>
                          <td className="py-4 whitespace-nowrap text-center capitalize notranslate">
                            {language["SUBTOTAL"]}
                          </td>
                        </tr>
                        {data?.orderProduct?.map((product) => (
                          <tr
                            key={product.id}
                            className="bg-white border-b hover:bg-gray-50"
                          >
                            <td className="pl-10 w-[400px] py-4 ">
                              <div className="flex space-x-6 items-center">
                                <div className="flex-1 flex flex-col">
                                  <p className="font-medium text-[15px] text-qblack rtl:text-right rtl:pr-10">
                                    {product?.product_name}
                                  </p>
                                </div>
                              </div>
                            </td>
                            <td className=" py-4">
                              <div className="flex justify-center items-center">
                                <div className="w-[54px] h-[40px] justify-center flex items-center border border-qgray-border">
                                  <span>{product?.qty}</span>
                                </div>
                              </div>
                            </td>
                            <td className="text-center py-4 px-2">
                              <div className="flex space-x-1 items-center justify-center">
                                <span className="text-[15px] font-normal">
                                  <span>$</span>
                                  <span>{product?.unit_price}</span>
                                </span>
                              </div>
                            </td>
                            <td className="text-center py-4 px-2">
                              <div className="flex space-x-1 items-center justify-center">
                                <span className="text-[15px] font-normal">
                                  <span>$</span>
                                  <span>
                                    {Number(product?.unit_price) *
                                      Number(product?.qty)}
                                  </span>
                                </span>
                              </div>
                            </td>
                          </tr>
                        ))}
                      </tbody>
                    </table>
                  </div>
                  <div className="flex sm:justify-end print:justify-end justify-center sm:mr-10">
                    <div>
                      <div className="flex justify-center gap-5 font-semibold  ">
                        <p className="text-lg text-qblack notranslate">
                          {language["Total Amount"]}
                        </p>
                        <p className="text-lg text-qblack">
                          <span>$</span>
                          <span>{Number(data?.order?.total_amount)}</span>
                        </p>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </>
          )}
        </Container>
      </section>

      {/* Update password */}
      <Modal isOpen={logOutModal} onClose={closeLogoutModal}>
        <div className="bg-white relative rounded-2xl p-10 w-full">
          <button
            className="absolute top-4 right-4"
            onClick={() => setUpdatePassword(false)}
          >
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="36"
              height="36"
              viewBox="0 0 36 36"
              fill="none"
            >
              <path
                d="M22.2426 22.2426L13.7574 13.7574M13.7574 22.2426L22.2426 13.7574M18 33C26.2843 33 33 26.2843 33 18C33 9.71573 26.2843 3 18 3C9.71573 3 3 9.71573 3 18C3 26.2843 9.71573 33 18 33Z"
                stroke="#EB5757"
                strokeWidth="1.5"
                strokeLinecap="round"
              />
            </svg>
          </button>
          <div className="flex flex-col items-center justify-center gap-5">
            <svg
              width="260"
              height="249"
              viewBox="0 0 260 249"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                d="M131.333 248.344C200.044 248.344 255.665 192.726 255.665 124.172C255.665 55.5487 199.975 0 131.333 0C62.6899 0 7 55.5487 7 124.103C7 192.726 62.6899 248.344 131.333 248.344Z"
                fill="url(#paint0_linear_493_13141)"
              />
              <path
                d="M28.7546 2.44425C29.2548 0.324572 32.2559 0.324572 32.7561 2.44425L34.4443 9.48907C34.6319 10.2372 35.1946 10.7983 35.9449 10.9853L43.0101 12.6686C45.1359 13.1673 45.1359 16.1598 43.0101 16.6586L35.9449 18.3419C35.1946 18.5289 34.6319 19.09 34.4443 19.8381L32.7561 26.8829C32.2559 29.0026 29.2548 29.0026 28.7546 26.8829L27.0664 19.8381C26.8789 19.09 26.3161 18.5289 25.5659 18.3419L18.5006 16.6586C16.3748 16.1598 16.3748 13.1673 18.5006 12.6686L25.5659 10.9853C26.3161 10.7983 26.8789 10.2372 27.0664 9.48907L28.7546 2.44425Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M125.837 11.3001C127.915 11.3001 129.647 9.57073 129.647 7.49544C129.647 5.42014 127.915 3.69073 125.837 3.69073C123.759 3.69073 122.027 5.42014 122.027 7.49544C122.027 9.57073 123.69 11.3001 125.837 11.3001ZM125.837 14.1364C129.508 14.1364 132.487 11.1618 132.487 7.49544C132.487 3.82908 129.508 0.854492 125.837 0.854492C122.166 0.854492 119.188 3.82908 119.188 7.49544C119.188 11.1618 122.166 14.1364 125.837 14.1364Z"
                fill="#8037A9"
              />
              <path
                d="M245.697 116.361C245.35 114.977 246.666 113.663 248.052 114.078L257.541 116.776C258.927 117.191 259.411 118.92 258.372 119.958L251.307 126.806C250.268 127.844 248.537 127.36 248.121 125.907L245.697 116.361Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M252.663 59.0042C254.741 59.0042 256.473 57.2748 256.473 55.1995C256.473 53.1242 254.741 51.3948 252.663 51.3948C250.585 51.3948 248.854 53.1242 248.854 55.1995C248.854 57.2748 250.585 59.0042 252.663 59.0042ZM252.663 61.8405C256.334 61.8405 259.313 58.8659 259.313 55.1995C259.313 51.5332 256.334 48.5586 252.663 48.5586C248.992 48.5586 246.014 51.5332 246.014 55.1995C246.014 58.8659 248.992 61.8405 252.663 61.8405Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M6.64955 72.3919C8.72753 72.3919 10.4592 70.6625 10.4592 68.5872C10.4592 66.5119 8.72753 64.7825 6.64955 64.7825C4.57156 64.7825 2.83991 66.5119 2.83991 68.5872C2.83991 70.6625 4.5023 72.3919 6.64955 72.3919ZM6.64955 75.2282C10.3206 75.2282 13.2991 72.2536 13.2991 68.5872C13.2991 64.9209 10.3206 61.9463 6.64955 61.9463C2.97844 61.9463 0 64.9209 0 68.5872C0 72.2536 2.97844 75.2282 6.64955 75.2282Z"
                fill="#8037A9"
              />
              <path
                d="M167 108H163V92C163 74.352 148.648 60 131 60C113.352 60 99 74.352 99 92V108H95C88.3867 108 83 113.381 83 120V176C83 182.619 88.3867 188 95 188H167C173.613 188 179 182.619 179 176V120C179 113.381 173.613 108 167 108ZM109.667 92C109.667 80.2347 119.235 70.6667 131 70.6667C142.765 70.6667 152.333 80.2347 152.333 92V108H109.667V92ZM136.333 149.184V161.333C136.333 164.277 133.949 166.667 131 166.667C128.051 166.667 125.667 164.277 125.667 161.333V149.184C122.493 147.333 120.333 143.931 120.333 140C120.333 134.117 125.117 129.333 131 129.333C136.883 129.333 141.667 134.117 141.667 140C141.667 143.931 139.507 147.333 136.333 149.184Z"
                fill="#8037A9"
              />
              <defs>
                <linearGradient
                  id="paint0_linear_493_13141"
                  x1="130.371"
                  y1="-40.5135"
                  x2="132.911"
                  y2="395.637"
                  gradientUnits="userSpaceOnUse"
                >
                  <stop stop-color="white" stopOpacity="0" />
                  <stop offset="1" stop-color="#8037A9" />
                </linearGradient>
              </defs>
            </svg>
            <h3 className="text-3xl font-bold text-dark-300 text-center">
              New Password has been Update
            </h3>
            <button
              onClick={() => setUpdatePassword(false)}
              className="py-3.5 w-full px-8 text-center font-medium text-white rounded transition bg-primary-200 hover:bg-primary-200/80"
            >
              Thanks
            </button>
          </div>
        </div>
      </Modal>
    </>
  );
}

export async function getServerSideProps({ query }) {
  return { props: { params: query.order_details } };
}
